@@ -1,15 +1,13 @@
 from macholib import dyld
-from macholib._compat import B
 
-import unittest
 import sys
 import os
 import functools
 
-try:
-    expectedFailure = unittest.expectedFailure
-except AttributeError:
-    expectedFailure = lambda function: function
+if sys.version_info[:2] <= (2,6):
+    import unittest2 as unittest
+else:
+    import unittest
 
 class DyldPatcher (object):
     def __init__(self):
@@ -65,7 +63,7 @@ class TestDyld (unittest.TestCase):
         def test_ensure_utf8(self):
             self.assertEqual(dyld._ensure_utf8("hello"), "hello")
             self.assertEqual(dyld._ensure_utf8(None), None)
-            self.assertRaises(ValueError, dyld._ensure_utf8, B("hello"))
+            self.assertRaises(ValueError, dyld._ensure_utf8, b"hello")
 
     def test__dyld_env(self):
         new = os.environ
@@ -339,7 +337,7 @@ class TestDyld (unittest.TestCase):
         self.assertEqual(result, '/usr/lib/libSystem.dylib')
         self.assertIsInstance(result, str) # bytes on 2.x, unicode on 3.x
 
-        result = dyld.dyld_find(B('/usr/lib/libSystem.dylib').decode('ascii'))
+        result = dyld.dyld_find(b'/usr/lib/libSystem.dylib'.decode('ascii'))
         self.assertEqual(result, '/usr/lib/libSystem.dylib')
         self.assertIsInstance(result, str) # bytes on 2.x, unicode on 3.x
 
@@ -394,7 +392,7 @@ class TestDyld (unittest.TestCase):
         self.assertEqual(result, '/System/Library/Frameworks/Cocoa.framework/Versions/Current/Cocoa')
         self.assertIsInstance(result, str) # bytes on 2.x, unicode on 3.x
 
-        result = dyld.framework_find(B('/System/Library/Frameworks/Cocoa.framework/Versions/Current/Cocoa').decode('latin1'))
+        result = dyld.framework_find(b'/System/Library/Frameworks/Cocoa.framework/Versions/Current/Cocoa'.decode('latin1'))
         self.assertEqual(result, '/System/Library/Frameworks/Cocoa.framework/Versions/Current/Cocoa')
         self.assertIsInstance(result, str) # bytes on 2.x, unicode on 3.x
 
